Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(984)

Unified Diff: content/common/frame_message_enums.h

Issue 1846653004: Rename IGNORING_CACHE to BYPASSING_CACHE (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/frame_message_enums.h
diff --git a/content/common/frame_message_enums.h b/content/common/frame_message_enums.h
index b93120607f50bdb5c3b75cb5032b858ae6a688f9..27e98433c75f339afee7cc1e4656f1a8ccd1b75b 100644
--- a/content/common/frame_message_enums.h
+++ b/content/common/frame_message_enums.h
@@ -10,11 +10,11 @@
struct FrameMsg_Navigate_Type {
public:
enum Value {
- // Reload the page.
+ // Reload the page, validating cache entries.
RELOAD,
- // Reload the page, ignoring any cache entries.
- RELOAD_IGNORING_CACHE,
+ // Reload the page, bypassing any cache entries.
+ RELOAD_BYPASSING_CACHE,
// Reload the page using the original request URL.
RELOAD_ORIGINAL_REQUEST_URL,

Powered by Google App Engine
This is Rietveld 408576698